<?php

function upper_key($array) {
  $stack = array();
  while (list ($key, $val) = each($array)) {
    $stack = array_merge($stack, array(strtoupper($key) => $val));
  }
  return $stack;
} 

function age_calc($seconds) {
  switch(true) {
    case($seconds < 60):
      return sprintf("%ds", $seconds);
      break;
    case($seconds < 3600):
      return sprintf("%1.1fm", ($seconds / 60));
      break;
    case($seconds < 86400):
      return sprintf("%1.1fh", ($seconds / 60 / 60));
      break;
    case($seconds < 31536000):
      return sprintf("%1.1fd", ($seconds / 60 / 60 / 24));
      break;
    default:
      return sprintf("%1.1fy", ($seconds / 60 / 60 / 24 / 365));
      break;
  }
}

function size_calc($bytes) {
  switch(true) {
    case($bytes < 1024):
      return sprintf("%d", $bytes);
      break;
    case($bytes < 1024000):
      return sprintf("%1.1fk", ($bytes / 1024));
      break;
    case($bytes < 1024000000):
      return sprintf("%1.1fm", ($bytes / 1024000));
      break;
    default:
      return sprintf("%1.1fg", ($bytes / 1024000000));
      break;
  }
}

function export_url($uri) {
  global $config;
  parse_str($uri, $uri_array);
  $uri_array['max-print'] = 0;
  $uri_array['export'] = "excel";
  return sprintf("%s/ezt-export.php?%s&summary=1&rand=%s", $config['baseurl'], query_str($uri_array), rand()); 
}


function page_calc_html($tickets, $page = 0, $tpp = 0, $uri) {
  global $config;
  $page++;
  parse_str($uri, $uri_array);

  // Maximum # of page links we want to display
  $max_pages = 5;
  $page_pad = floor($max_pages / 2);

  if ($tpp <= 0)
    return "";

  // Calc total # of pages
  $total_pages = ceil($tickets / $tpp);

  if ($total_pages <= 1)
    return "";

  // Get start page
  $start_page = $page - $page_pad;
  if ($start_page <= 0)
    $start_page = 1;

  // Get end page
  $end_page = $page + $page_pad + ($page_pad - ($page - $start_page));
  if ($end_page > $total_pages)
    $end_page = $total_pages;

  // Build starting "<<" link
  if ($start_page - $page_pad >= 1) {
    $uri_array['page'] = $start_page - $page_pad - 1;
    $html = sprintf(" <A HREF=\"%s/ezt-list.php?%s\">&lt;&lt;</a> | ", $config['baseurl'], query_str($uri_array)); 
  }

  // Begin HTML building
  for ($i = $start_page; $i <= $end_page; $i++) {
    if ($i == $page)
      $html .= sprintf(" <B>%s</B> ", $i); 
    else {
      $uri_array['page'] = $i;
      $html .= sprintf(" <A HREF=\"%s/ezt-list.php?%s\">%s</a> ", $config['baseurl'], query_str($uri_array), $i); 
    }
    if ($i != $total_pages)
      $html .= "|"; 
  }
  
  // Build starting ">>" link
  if ($end_page + $page_pad <= $total_pages) {
    $uri_array['page'] = $end_page + $page_pad + 1;
    $html .= sprintf(" <A HREF=\"%s/ezt-list.php?%s\">&gt;&gt;</a> ", $config['baseurl'], query_str($uri_array)); 
  }

  return $html;
}

function query_str ($params) {
  $str = '';
  foreach ($params as $key => $value) {
    $str .= (strlen($str) < 1) ? '' : '&';
    if (is_array($value))
      $str .= query_str_array($key, $value);
    else
      $str .= $key . '=' . rawurlencode($value);
  }
  return ($str);
}

function query_str_array ($parrentkey, $params) {
  $str = '';
  foreach ($params as $key => $value) {
    $str .= (strlen($str) < 1) ? '' : '&';
    if (is_array($value)) {
      $pkey .= $parrentkey . "[" . $key . "]";
      $str .= query_str_array($pkey, $value);
    } else
      $str .= $parrentkey . "[" . $key . ']=' . rawurlencode($value);
  }
  return ($str);
}


function ezt_status_html($status) {
  switch($status) {
    case OPEN:
      return sprintf("<FONT COLOR=\"RED\">Open</FONT>");
      break;
    case DONE:
      return sprintf("<FONT COLOR=\"BLUE\">Done</FONT>");
      break;
    case CLOSED:
      return sprintf("<FONT COLOR=\"GREEN\">Closed</FONT>");
      break;
    case REOPENED:
      return sprintf("<FONT COLOR=\"ORANGE\">ReOpened</FONT>");
      break;
  }
}

function ezt_status_text($status) {
  switch($status) {
    case OPEN:
      return "Open";
      break;
    case DONE:
      return "Done";
      break;
    case CLOSED:
      return "Closed";
      break;
    case REOPENED:
      return "ReOpened";
      break;
  }
}

function ezt_user_html($user_userid, $user_username, $ticket_owner_id) {
  if(is_array($user_userid) && in_array($ticket_owner_id, $user_userid))
    return sprintf("<font color=\"red\"><b>%s</b></font>", $user_username);
  elseif (!is_array($user_userid) && $user_userid == $ticket_owner_id)
    return sprintf("<font color=\"red\"><b>%s</b></font>", $user_username);
  else
    return sprintf("<font color=\"blue\">%s</font>", $user_username);
}

function ezt_severity_html($severity) {
  switch($severity) {
    case 0:
      return sprintf("<BLINK><FONT COLOR=\"#FF0000\">Sev-%s</FONT></BLINK>",$severity);
      break;
    case 1:
    case 2:
      return sprintf("<FONT COLOR=\"#FF0000\">Sev-%s</FONT>",$severity);
      break;
    case 3:
      return sprintf("<FONT COLOR=\"808000\">Sev-%s</FONT>",$severity);
      break;
    case 4:
    case 5:
      return sprintf("<FONT COLOR=\"GREEN\">Sev-%s</FONT>",$severity);
      break;
  }
}

function ezt_priority_html($priority) {
  switch($priority) {
    case 0:
      return sprintf("<BLINK><FONT COLOR=\"#FF0000\">%s</FONT></BLINK>",$priority);
      break;
    case 1:
      return sprintf("<FONT COLOR=\"#CC3300\">%s</FONT>",$priority);
      break;
    case 2:
      return sprintf("<FONT COLOR=\"#993300\">%s</FONT>",$priority);
      break;
    default:
      return sprintf("%s",$priority);
      break;
  }
}

function fillspace($in_array) {
  $out_array = array();
  if (is_array($in_array)) {
    while(list($key, $val) = each($in_array)) {
      if(empty($val))
        $val = "&nbsp;"; 
      $out_array = array_merge($out_array, array($key => $val));
    }
  }
  return $out_array;
}

// Error and redirect functions
function error_message($msg) {
   echo "<SCRIPT>alert(\"Error: $msg\");history.go(-1)</SCRIPT>";
   exit;
}
                                                                                                                                                            
function error_message_redirect($msg, $url) {
   echo "<SCRIPT>alert(\"Error: $msg\");window.location=\"$url\"</SCRIPT>";
   exit;
}
                                                                                                                                                            
function popup_message_redirect($msg, $url) {
   echo "<SCRIPT>alert(\"Notice: $msg\");window.location=\"$url\"</SCRIPT>";
   exit;
}
                                                                                                                                                            
function javascript_redirect($url) {
   echo "<SCRIPT>window.location=\"$url\"</SCRIPT>";
   exit;
}
                                                                                                                                                            
function popup_message($msg) {
   return "<SCRIPT>alert(\"$msg\")</SCRIPT>";
   exit;
}

?>
